import { ValueTransformer } from './../dynaform/interfaces';
import * as fmd from './../dynaform/models'; // fmd = Form Meta Data

const basicTextField = new fmd.TextField({
	name: 'basicTextField',
	label: 'Field One',
	placeholder: 'Type a value here'
});

const styledTextField = new fmd.TextField({
	name: 'styledTextField',
	placeholder: 'With a DOM id and CSS classes applied',
	class: ['red', 'bgPaleBlue'],
	id: 'yoyo'
});

const textareaField = new fmd.TextareaField({
	name: 'textareaField',
	placeholder: 'Type your long-winded comments here'
});

const passwordField = new fmd.PasswordField({
	name: 'passwordField',
	placeholder: 'It\'s a secret'
});

const checkButton = new fmd.CheckbuttonField({
	name: 'checkButton',
	value: '456'
});

const modifiers = ['Matches', 'Starts With', 'Contains'];
const transformerFunctions: ValueTransformer = {
	inputFn: val => {
		let modifier = 'Starts With';
		if (/^%.*?%$/.test(val)) {
			modifier = 'Contains';
		} else if (/^[^%].*?[^%]$/.test(val)) {
			modifier = 'Matches';
		} else if (/^%.*/.test(val)) {
			modifier = 'Starts With';
		}
		const transformedVal = val.replace(/%/g, '').trim();
		return { modifier: modifier, value: transformedVal };
	},
	outputFn: (mod, val) => {
		let transformedValue;
		switch(mod) {
			case 'Starts With':
				transformedValue = `%${val}`;
				break;
			case 'Contains':
				transformedValue = `%${val}%`;
				break;
			case 'Matches':
			default:
				transformedValue = val;
				break;
		}
		return transformedValue;
	}
};
const dropDownModifiedInput = new fmd.DropdownModifiedInputField({
	name: 'dropDownModifiedInput',
	value: 'lovely',
	modifiers,
	transform: transformerFunctions
});

// ---------------------------------------------------------------------------------------------------------------------

export const formMetaDataObj = {
	basicTextField,
	styledTextField,
	textareaField,
	passwordField,
	checkButton,
	dropDownModifiedInput
};
